c **********************************************************************
      subroutine atmosinit(atmosfile)
c ----------------------------------------------------------------------
c   Reads in a two-column array containing wavelengths and fluxes
c   Calculates partial integrals at every wavelength point
c   Normalizes the integrals on the bolometric flux
c   Uses real function tr2 for integration
c-----------------------------------------------------------------------
c                                [Anatoly Miroshnichenko, Mar. 1998]
c
c     b.a.whitney July 2002, bug in sampling (atmosfreq), can't find it, 
c     rewriting to something I can understand:
c     reorder frequency array, linearly interpolate cdf
c     aug 2004, baw, increase nHumax=28000 for nextgen models
c     change all atmosphere files to have only 1 header line.
c ======================================================================       
      
      implicit none
      
      include 'dust.com'
      
      integer nHnu,nHnumax
      parameter(nHnumax=28000)
      real*8 atmosnu,Hnuint
      dimension atmosnu(nHnumax),Hnuint(nHnumax)
      common /atmos_interp/atmosnu,Hnuint,nHnu

      CHARACTER*80 atmosfile
      CHARACTER*80 header1,header2,header3
      INTEGER i,n
      REAL*8 winv(nHnumax),ftmp(nHnumax),f(nHnumax),chif(nHnumax)
     +     winvtmp(nHnumax),fbol,tr2
c-----------------------------------------------------------------------

      open(21,file=atmosfile,status='old')
      read(21,*) header1
      
      do i=1,nHnumax
         read(21,*,end=100) wtmp,winv(i),ftmp(i)
      enddo
      
      write(*,*) 'atmosinit: too many frequencies in model atmosphere'
      stop

 100  close(21)

      nHnu=i-1   
      write(*,*) 'nHnu=',nHnu

c     reorder arrays with increasing frequency
       do i=1,nHnu
          winv(nHnu-i+1)=winvtmp(i)
          f(nHnu-i+1)=ftmp(i)
       enddo

c     integrate pdf
       do i=1,nHnu
          atmosnu(i)=1.2398*winv(i)
          call opacset(atmosnu(i))
          chif(i)=kappa*f(i)

          if(i.eq.1) then
             Hnuint(i)=0.
          else
             Hnuint(i)=Hnuint(i-1)+0.5*(f(i)+f(i-1))*(winv(i)-winv(i-1))
          endif
      end do
      
      fbol=Hnuint(nHnu)
      kappaf=0.
      do i=1,nHnu
            Hnuint(i)=Hnuint(i)/fbol
            kappaf=kappaf+0.5*(chif(i)+chif(i-1))*(winv(i)-winv(i-1))
      end do
      kappaf=kappaf/fbol

      fbol=fbol*2.997925e14
      write(*,*) 'Teff,kappaf=',(4.*3.141593*fbol/5.67051e-5)**0.25,
     +           kappaf

      return
      end

      

      real function atmosfreq()

c     baw, July 2002

      implicit none

      include 'random.com'
      
      integer i
      real xi

      integer nHnu,nHnumax
      parameter(nHnumax=25000)
      real*8 atmosnu,Hnuint
      dimension atmosnu(nHnumax),Hnuint(nHnumax)
      common /atmos_interp/atmosnu,Hnuint,nHnu

      real ran2

      
      xi=ran2(idum)

      call locate(Hnuint,nHnu,xi,i)

      atmosfreq=atmosnu(i)+(atmosnu(i+1)-atmosnu(i))*(xi-Hnuint(i))

      return
      end
