      SUBROUTINE REAPAR(cflpar,iopar,atname,dustname
     &     )

C***********************************************************************
C Subroutine REAPAR handles the reading of input parameters from the
C ".par" file, as well as elementary processing with those input
C parameters to generate arrays.
c
C Original version created by P.J.Flatau, Colorado State Univ.
C Modified by B.T.Draine, Princeton Univ. Obs.
C ported from program DDSCAT by m. wolff
c
C History:
C 95/01/17 (mjw): stripped out of DDSCAT and ported to BLOB
C 99/12/02 (mjw): stripped out of BLOB and ported to MCTHERM
c                 parameter OCCULT defined in calling routine (SETUP)
c 00/03/19 (mjw): added some Vger stuff (Vger position in units of rmax)
c 00/06/30 (baw): redo some spot input
c 00/07/27 (mjw): remove extraneous commas that drove lf95 crazy
c                   (occurrences of "write(*,*),something")
c 03/08/13 (baw): get rid of parameters that confuse outside users
c 05/01/31 (baw): get rid of TTS-specific parameters, to make more general
C
C***********************************************************************
C

      implicit none

C     .. Scalar Arguments ..
      character cflpar*(*),atname*80,dustname(4)*80
      integer iopar


C     .. Local Scalars ..
      character cline*70,cmsgnm*70
      character*3 cbub,chole,climb,cpeel,cpoly,cstream,czmin
      character*5 cshape
     1   ,cwrite,cspot,cveeg,cnspot,cdiskacc,crminsub
C     ..
C     .. Local Arrays ..
C     ..
C     .. External Subroutines ..
      external errmsg, wrimsg
C     ..
C     .. Intrinsic Functions ..
C     ..
C     .. Data statements ..
C     ..
c     .. Include statements ..

      include 'opacin.txt'
      include 'out.txt'
      include 'random.txt'
      include 'tabl.txt'
      include 'tts.txt'
      include 'spot.txt'
      include 'vger.txt'


C***********************************************************************

      open(unit=iopar,file=cflpar,status='old')

      READ(IOPAR,FMT=*,ERR=40)CLINE
      CALL WRIMSG(' ',CLINE)

C***********************************************************************
C ... Preliminaries
c
      READ(IOPAR,FMT=*,ERR=40)CLINE
      CALL WRIMSG(' ',CLINE)

      READ(IOPAR,FMT=*,ERR=40)np
      WRITE(CMSGNM,FMT='(i11,a)')np
     &     ,' = NP = Number of photons from central star'
      CALL WRIMSG('REAPAR',CMSGNM)

c      READ(IOPAR,FMT=*,ERR=40) accfrac
c      WRITE(CMSGNM,FMT='(1pe13.6,a)') accfrac
c     &     ,' = ACCFRAC = fraction of accretion luminosity'
c      CALL WRIMSG('REAPAR',CMSGNM)

c      READ(IOPAR,FMT=*,ERR=40) mdot
c      WRITE(CMSGNM,FMT='(1pe13.6,a)') mdot
c     &     ,' = MDOTD = Disk accretion rate'
c      CALL WRIMSG('REAPAR',CMSGNM)


c      READ(IOPAR,FMT=*,ERR=40)npout
c      WRITE(CMSGNM,FMT='(i11,a)')npout
c     &     ,' = NPOUT = Number of photons from outside star'
c      CALL WRIMSG('REAPAR',CMSGNM)
      npout=0

      READ(IOPAR,FMT=*,ERR=40)i1
      WRITE(CMSGNM,FMT='(i10,a)')i1
     &     ,' = I1 = random number seed'
      CALL WRIMSG('REAPAR',CMSGNM)
      i1=-(abs(i1))
      READ(IOPAR,FMT=*,ERR=40)iwrite
      WRITE(CMSGNM,FMT='(i9,a)')iwrite
     &     ,' = IWRITE = no. of photons between timing calls'
      CALL WRIMSG('REAPAR',CMSGNM)
c      READ(IOPAR,FMT=*,ERR=40)ctherm
c      if ( (ctherm.eq.'YES').OR.(ctherm.eq.'yes') ) then
c         itherm = 1
c         WRITE(CMSGNM,FMT='(a)')
c     &        ,'ITHERM=1, Calculating thermal emission + scattering'
c      else
c         itherm = 0
c         WRITE(CMSGNM,FMT='(a)')
c     &        ,'ITHERM=0, Calculating ONLY scattering'
c      endif
c      CALL WRIMSG('REAPAR',CMSGNM)
      READ(IOPAR,FMT=*,ERR=40)cpeel
      if ( (cpeel.eq.'YES').OR.(cpeel.eq.'yes') ) then
         ipeel = 1
         WRITE(CMSGNM,FMT='(a)')
     &        'IPEEL=1, Using peeling-off procedure'
      else
         ipeel = 0
         WRITE(CMSGNM,FMT='(a)')
     &        'IPEEL=0, Using standard MC (no peeling-off)'
      endif
      CALL WRIMSG('REAPAR',CMSGNM)

c      READ(IOPAR,FMT=*,ERR=40)cveeg
c      if ( (cveeg.eq.'YES').OR.(cveeg.eq.'yes') ) then
c         iveeg = 1
c         WRITE(CMSGNM,FMT='(a)')
c     &        'IVEEG=1, calculating radiation field at point inside'
c      else
c         iveeg = 0
c         WRITE(CMSGNM,FMT='(a)')
c     &        'IVEEG=0, not calculating rad. field at point inside'
c      endif
c      CALL WRIMSG('REAPAR',CMSGNM)
      iveeg=0

c      READ(IOPAR,FMT=*,ERR=40)cwrite
c      if ( (cwrite.eq.'YES').OR.(cwrite.eq.'yes') ) then
c         iwriteim = 1
c         WRITE(CMSGNM,FMT='(a)')
c     &        'IWRITEIM=1, writing out all images'
c      else
c         iwriteim = 0
c         WRITE(CMSGNM,FMT='(a)')
c     &        'IWRITEIM=0, only writing peeling-off images'
c      endif
c      CALL WRIMSG('REAPAR',CMSGNM)

      READ(IOPAR,FMT=*,ERR=40)climb
      if ( (climb.eq.'YES').OR.(climb.eq.'yes') ) then
         limb = 1
         WRITE(CMSGNM,FMT='(a)')
     &        'LIMB=1, Limb-darkening for central source'
      else
         limb = 0
         WRITE(CMSGNM,FMT='(a)')
     &        'LIMB=0, NO limb-darkening for central source'
      endif
      CALL WRIMSG('REAPAR',CMSGNM)

      READ(IOPAR,FMT=*,ERR=40) atname
c      WRITE(CMSGNM,FMT='(a,a)')
c     &     atname,' = atmosphere file'
c      CALL WRIMSG('REAPAR',CMSGNM)
      print*,atname,' = atmosphere file'

      READ(IOPAR,FMT=*,ERR=40) dustname(1)
c      WRITE(CMSGNM,FMT='(a,a)')
c     &     dustname,' = dust file'
c      CALL WRIMSG('REAPAR',CMSGNM)
      print*,dustname(1),' = dust file'

      READ(IOPAR,FMT=*,ERR=40) dustname(2)
c      WRITE(CMSGNM,FMT='(a,a)')
c     &     dustname,' = dust file'
c      CALL WRIMSG('REAPAR',CMSGNM)
      print*,dustname(2),' = dust file'

      READ(IOPAR,FMT=*,ERR=40) dustname(3)
c      WRITE(CMSGNM,FMT='(a,a)')
c     &     dustname,' = dust file'
c      CALL WRIMSG('REAPAR',CMSGNM)
      print*,dustname(3),' = dust file'

      READ(IOPAR,FMT=*,ERR=40) dustname(4)
c      WRITE(CMSGNM,FMT='(a,a)')
c     &     dustname,' = dust file'
c      CALL WRIMSG('REAPAR',CMSGNM)
      print*,dustname(4),' = dust file'

C***********************************************************************
C ... Central source properties
c
      READ(IOPAR,FMT=*,ERR=40)CLINE
      CALL WRIMSG(' ',CLINE)

      READ(IOPAR,FMT=*,ERR=40)rstar
      WRITE(CMSGNM,FMT='(1pe13.6,a)')rstar
     &     ,' = RSTAR = Stellar radius in Solar radii'
      CALL WRIMSG('REAPAR',CMSGNM)

      READ(IOPAR,FMT=*,ERR=40)tstar
      WRITE(CMSGNM,FMT='(1pe13.6,a)')tstar
     &     ,' = TSTAR = Blackbody temperature of central star (K)'
      CALL WRIMSG('REAPAR',CMSGNM)

      READ(IOPAR,FMT=*,ERR=40)massc
      WRITE(CMSGNM,FMT='(1pe13.6,a)')massc
     &     ,' = MASSC = Mass of central star (for TSC properties)'
      CALL WRIMSG('REAPAR',CMSGNM)

c      READ(IOPAR,FMT=*,ERR=40) cspot
c      if ( (cspot.eq.'YES').OR.(cspot.eq.'yes') ) then
c         ispot = 1
c         WRITE(CMSGNM,FMT='(a)')
c     &        'ISPOT=1, emission from star+spot'
c	   spotflag = 1   !require to run spotset first time
c      else
c         ispot = 0
c         WRITE(CMSGNM,FMT='(a)')
c     &        'ISPOT=0, uniform emission from star'
c      endif
c      CALL WRIMSG('REAPAR',CMSGNM)

c      READ(IOPAR,FMT=*,ERR=40)tspot
c      WRITE(CMSGNM,FMT='(1pe13.6,a)')tspot
c     &     ,' = TSTAR = Blackbody temperature of spot (K)'
c      CALL WRIMSG('REAPAR',CMSGNM)

c      READ(IOPAR,FMT=*,ERR=40)thspot
c      WRITE(CMSGNM,FMT='(1pe13.6,a)')thspot
c     &     ,' = THSPOT = radius of spot in degrees'
c      CALL WRIMSG('REAPAR',CMSGNM)

c      READ(IOPAR,FMT=*,ERR=40)thspotin
c      WRITE(CMSGNM,FMT='(1pe13.6,a)')thspotin
c     &     ,' = THSPOTIN = inner radius of spot (for ring)'
c      CALL WRIMSG('REAPAR',CMSGNM)

c      READ(IOPAR,FMT=*,ERR=40)spotlat
c      WRITE(CMSGNM,FMT='(1pe13.6,a)')spotlat
c     &     ,' = SPOTLAT = latitude of spot (degrees)'
c      CALL WRIMSG('REAPAR',CMSGNM)

c      READ(IOPAR,FMT=*,ERR=40)spotlon
c      WRITE(CMSGNM,FMT='(1pe13.6,a)')spotlon
c     &     ,' = SPOTLON = longitude of spot (degrees)'
c      CALL WRIMSG('REAPAR',CMSGNM)

c      READ(IOPAR,FMT=*,ERR=40) cnspot
c      if ( (cnspot.eq.'ONE').OR.(cnspot.eq.'one') ) then
c         nspot = 1
c         WRITE(CMSGNM,FMT='(a)')
c     &        'NSPOT=1, one spot'
c      else
c         nspot = 2
c         WRITE(CMSGNM,FMT='(a)')
c     &        'NSPOT=2, two spots'
c      endif
c      CALL WRIMSG('REAPAR',CMSGNM)

C***********************************************************************
C ... Disk properties
c
      READ(IOPAR,FMT=*,ERR=40)CLINE
      CALL WRIMSG(' ',CLINE)
      READ(IOPAR,FMT=*,ERR=40)massd
      WRITE(CMSGNM,FMT='(1pe13.6,a)')massd
     &     ,' = MASSD = Disk mass in solar masses'
      CALL WRIMSG('REAPAR',CMSGNM)
      print*,'massd',massd
      READ(IOPAR,FMT=*,ERR=40)rmaxd
      WRITE(CMSGNM,FMT='(1pe13.6,a)')rmaxd
     &     ,' = RMAXD = Maximum disk radius'
      CALL WRIMSG('REAPAR',CMSGNM)

      READ(IOPAR,FMT=*,ERR=40) crminsub
      if ( (crminsub.eq.'YES').OR.(crminsub.eq.'yes') ) then
         irminsub = 1
         WRITE(CMSGNM,FMT='(a)')
     &        'IRMINSUB=1, scaling RMINE,RMIND to dust sub. radius'
      else
         irminsub = 0
         WRITE(CMSGNM,FMT='(a)')
     &        'IRMINSUB=0, scaling RMINE,RMIND to Rstar'
      endif
      CALL WRIMSG('REAPAR',CMSGNM)

      READ(IOPAR,FMT=*,ERR=40)rmind_in
      WRITE(CMSGNM,FMT='(1pe13.6,a)')rmind_in
     &     ,' = RMIND = Maximum disk radius'
      CALL WRIMSG('REAPAR',CMSGNM)
c      READ(IOPAR,FMT=*,ERR=40)rddust
c      WRITE(CMSGNM,FMT='(1pe13.6,a)')rddust
c     &     ,' = RDDUST = Minimum disk opacity radius in Rstar'
c      CALL WRIMSG('REAPAR',CMSGNM)
      rddust=rmind_in
      rmind=rmind_in

      READ(IOPAR,FMT=*,ERR=40) czmin
      if ( (czmin.eq.'YES').OR.(czmin.eq.'yes') ) then
         izmin = 1
         WRITE(CMSGNM,FMT='(a)')
     &   'IZMIN=1, calculating disk scale height based on hseq at Rsub'
      else
         izmin = 0
         WRITE(CMSGNM,FMT='(a)')
     &    'IZMIN=0, using user input for ZMIN (scale height at Rstar)'
      endif
      CALL WRIMSG('REAPAR',CMSGNM)

      READ(IOPAR,FMT=*,ERR=40)zmin
      WRITE(CMSGNM,FMT='(1pe13.6,a)')zmin
     &     ,' = ZMIN = Scale height of disk at Rstar'
      CALL WRIMSG('REAPAR',CMSGNM)
      READ(IOPAR,FMT=*,ERR=40)a
      WRITE(CMSGNM,FMT='(1pe13.6,a)')a
     &     ,' = A = Disk density exponent (~ r^(-a))'
      CALL WRIMSG('REAPAR',CMSGNM)
      READ(IOPAR,FMT=*,ERR=40)b
      WRITE(CMSGNM,FMT='(1pe13.6,a)')b
     &     ,' = B = Disk scale height exponent (~ r^(b))'
      CALL WRIMSG('REAPAR',CMSGNM)

c      READ(IOPAR,FMT=*,ERR=40) cdiskacc
c      if ( (cdiskacc.eq.'YES').OR.(cdiskacc.eq.'yes') ) then
c         idiskacc = 1
c         WRITE(CMSGNM,FMT='(a)')
c     &        'IDISKACC=1, Including disk accretion luminosity'
c      else
c         idiskacc = 0
c         WRITE(CMSGNM,FMT='(a)')
c     &        'IDISKACC=0, not including disk accretion luminosity'
c      endif
c      CALL WRIMSG('REAPAR',CMSGNM)
      cdiskacc='NO'
      idiskacc=0

c      READ(IOPAR,FMT=*,ERR=40) alphad
c      WRITE(CMSGNM,FMT='(1pe13.6,a)') alphad
c     &     ,' = ALPHAD = alpha disk parameter'
c      CALL WRIMSG('REAPAR',CMSGNM)
      alphad=0.

c      READ(IOPAR,FMT=*,ERR=40) rtrunc
c      WRITE(CMSGNM,FMT='(1pe13.6,a)') rtrunc
c     &     ,' = RTRUNC = magnetosphere co-rotation radius'
c      CALL WRIMSG('REAPAR',CMSGNM)
      rtrunc=rmind
     
c      READ(IOPAR,FMT=*,ERR=40) fspot
c      WRITE(CMSGNM,FMT='(1pe13.6,a)') fspot
c     &     ,' = FSPOT = fractional area of spot'
c      CALL WRIMSG('REAPAR',CMSGNM)
      fspot=1.

C***********************************************************************
C ... Envelope properties
c
      READ(IOPAR,FMT=*,ERR=40)CLINE
      CALL WRIMSG(' ',CLINE)

      READ(IOPAR,FMT=*,ERR=40)rmax
      WRITE(CMSGNM,FMT='(1pe13.6,a)')rmax
     &     ,' = RMAX = Maximum envelope radius in AU'
      CALL WRIMSG('REAPAR',CMSGNM)

      READ(IOPAR,FMT=*,ERR=40)rmine_in
      WRITE(CMSGNM,FMT='(1pe13.6,a)')rmine_in
     &     ,' = RMINE = Minimum envelope radius in AU'
      CALL WRIMSG('REAPAR',CMSGNM)
      rmine=rmine_in

      READ(IOPAR,FMT=*,ERR=40) expe
      WRITE(CMSGNM,FMT='(1pe13.6,a)') expe
     &     ,' = EXPE = density exponent for envelope'
      CALL WRIMSG('REAPAR',CMSGNM)

      READ(IOPAR,FMT=*,ERR=40) f_ellips
      WRITE(CMSGNM,FMT='(1pe13.6,a)') f_ellips
     &     ,' = F_ELLIPS = factor for ellipsoidal envelope'
      CALL WRIMSG('REAPAR',CMSGNM)

      READ(IOPAR,FMT=*,ERR=40) rhoe0
      WRITE(CMSGNM,FMT='(1pe13.6,a)') rhoe0
     &    ,' = RHOE0 = fiducial density for envelope at RMINE'
      CALL WRIMSG('REAPAR',CMSGNM)

c      READ(IOPAR,FMT=*,ERR=40)rate
c      WRITE(CMSGNM,FMT='(1pe13.6,a)')rate
c     &     ,' = RATE = Mass infall rate for TSC env.'//
c     &     '(M_O/yr)'
c      CALL WRIMSG('REAPAR',CMSGNM)
      rate=0.
c      READ(IOPAR,FMT=*,ERR=40)rc
c      WRITE(CMSGNM,FMT='(1pe13.6,a)')rc
c     &     ,' = RC = centrifugal radius for TSC env.'
c      CALL WRIMSG('REAPAR',CMSGNM)
      rc=0.
      READ(IOPAR,FMT=*,ERR=40)chole
c      READ(IOPAR,FMT=*,ERR=40)cshape
      cshape='POLYN'
c      READ(IOPAR,FMT=*,ERR=40)rchole  
      rchole=0.
      READ(IOPAR,FMT=*,ERR=40)thet1
c      READ(IOPAR,FMT=*,ERR=40)thet2
      READ(IOPAR,FMT=*,ERR=40)ex1
c      READ(IOPAR,FMT=*,ERR=40)ex2
      READ(IOPAR,FMT=*,ERR=40)z01
c      READ(IOPAR,FMT=*,ERR=40)z02
      READ(IOPAR,FMT=*,ERR=40)exf
      READ(IOPAR,FMT=*,ERR=40)rhoconst1
c      READ(IOPAR,FMT=*,ERR=40)rhoconst2
      READ(IOPAR,FMT=*,ERR=40)rhoamb

      thet2=thet1
      ex2=ex1
      z02=z01
      rhoconst2=rhoconst1

      if ( (chole.eq.'YES').OR.(chole.eq.'yes') ) then
         ihole = 1
         WRITE(CMSGNM,FMT='(a)')
     &        'IHOLE=1, Carving cavity out'
         CALL WRIMSG('REAPAR',CMSGNM)
         WRITE(CMSGNM,FMT='(f6.1,a)')thet1
     &        ,' = THET1 = Opening angle of cavity wall'
c         CALL WRIMSG('REAPAR',CMSGNM)
c         WRITE(CMSGNM,FMT='(f6.1,a)')thet2
c     &        ,' = THET2 = Opening angle of outer cavity wall'
c         CALL WRIMSG('REAPAR',CMSGNM)

         WRITE(CMSGNM,FMT='(f7.2,a)')ex1
     &        ,' = EX1 = Cavity wall exponent'
         CALL WRIMSG('REAPAR',CMSGNM)

         thetmu0=thet2
         if (cshape.eq.'STREAM') then
            ipoly=0
            istream=1
            WRITE(CMSGNM,FMT='(a)')
     &           'cavit is streamline shape'
            WRITE(CMSGNM,FMT='(1pe11.4,a)')rchole
     &           ,' = RCHOLE = Streamline hole size in AU'
            CALL WRIMSG('REAPAR',CMSGNM)
            WRITE(CMSGNM,FMT='(f6.2,a)')thetmu0
     &           ,' = THETMU0 = Opening angle of streamline hole (deg)'
         else
            ipoly = 1
            istream=0
            WRITE(CMSGNM,FMT='(a)')
     &           'Polynomial-shaped cavity'
            WRITE(CMSGNM,FMT='(f7.2,a)')ex1
     &           ,' = EX1 =Cavity wall exponent'
            CALL WRIMSG('REAPAR',CMSGNM)
         endif

         WRITE(CMSGNM,FMT='(1pe11.4,a)')z01
     &        ,' = Z01 = Height of wall at w=0'
         CALL WRIMSG('REAPAR',CMSGNM)
c         WRITE(CMSGNM,FMT='(1pe11.4,a)')z02
c     &        ,' = Z02 = Height of outer wall at w=0'
c         CALL WRIMSG('REAPAR',CMSGNM)
         WRITE(CMSGNM,FMT='(f7.2,a)')exf
     &        ,' = EXF = exponent for cavity density power-law'
         CALL WRIMSG('REAPAR',CMSGNM)
         WRITE(CMSGNM,FMT='(1pe11.4,a)')rhoconst1
     &        ,' = RHOCONST1 = Coefficient for cavity density'
         CALL WRIMSG('REAPAR',CMSGNM)
c         WRITE(CMSGNM,FMT='(1pe11.4,a)')rhoconst2
c     &        ,' = RHOCONST2 = Coefficient for outer cavity density'
c         CALL WRIMSG('REAPAR',CMSGNM)
         WRITE(CMSGNM,FMT='(1pe11.4,a)')rhoamb
     &        ,' = RHOAMB = ambient density'
         CALL WRIMSG('REAPAR',CMSGNM)

c         if ( (cstream.eq.'YES').OR.(cstream.eq.'yes') ) then
c            istream = 1
c            WRITE(CMSGNM,FMT='(a)')
c     &           'ISTREAM=1, streamline hole'
c            CALL WRIMSG('REAPAR',CMSGNM)
c         
c         else
c            istream = 0
c            WRITE(CMSGNM,FMT='(a)')
c     &           'ISTREAM=0'
c         endif
      else
         ihole = 0
         WRITE(CMSGNM,FMT='(a)')
     &        'IHOLE=0, NO cavity'
      endif
      CALL WRIMSG('REAPAR',CMSGNM)

c      READ(IOPAR,FMT=*,ERR=40)cbub
c      READ(IOPAR,FMT=*,ERR=40)nbub
c      READ(IOPAR,FMT=*,ERR=40)zbub1
c      READ(IOPAR,FMT=*,ERR=40)zbub2
c      READ(IOPAR,FMT=*,ERR=40)buboa
c      if ( (cbub.eq.'YES').OR.(cbub.eq.'yes') ) then
c         ibub = 1
c         WRITE(CMSGNM,FMT='(a)')
c     &        'IBUB=1, including bubble'
c         CALL WRIMSG('REAPAR',CMSGNM)
c         WRITE(CMSGNM,FMT='(f7.2,a)')nbub
c     &        ,' = NBUB = Exponent describing bubble shape'
c         CALL WRIMSG('REAPAR',CMSGNM)
c         WRITE(CMSGNM,FMT='(1pe11.4,a)')zbub1
c     &        ,' = ZBUB1 = height of bubble inner wall'
c         CALL WRIMSG('REAPAR',CMSGNM)
c         WRITE(CMSGNM,FMT='(1pe11.4,a)')zbub2
c     &        ,' = ZBUB2 = height of bubble outer wall'
c         CALL WRIMSG('REAPAR',CMSGNM)
c         WRITE(CMSGNM,FMT='(1pe11.4,a)')buboa
c     &        ,' = BUBOA = Opening angle of hole in bubble'
c      else
c         ibub = 0
c         WRITE(CMSGNM,FMT='(a)')
c     &        'IBUB=0, NO bubble'
c      endif
c      CALL WRIMSG('REAPAR',CMSGNM)

      cbub='NO'
      nbub=4
      zbub1=250.
      zbub2=300.
      buboa=0.0

C***********************************************************************
C ... Vger stuff
c
c XVG0,YVG0,ZVG0 = location of VGER in units of RMAX
c XSRC0,YSRC0,ZSRC0 = location of outer illum. (RMAX)
c ISRC0,QSRC0,USRC0,VSRC0 = normalized stokes for incident outside illum.
c
c      READ(IOPAR,FMT=*,ERR=40)CLINE
c      CALL WRIMSG(' ',CLINE)
c      READ(IOPAR,FMT=*,ERR=40)xvg0,yvg0,zvg0
c      READ(IOPAR,FMT=*,ERR=40)xsrc0,ysrc0,zsrc0
c      READ(IOPAR,FMT=*,ERR=40)isrc0,qsrc0,usrc0,vsrc0
c      if (CVEEG.eq.'YES') then
c         write(CMSGNM,fmt='(3(1pe11.4,1x),a)') xvg0,yvg0,zvg0,
c     &        ' - VGER location in units of RMAX'
c         CALL WRIMSG('REAPAR',CMSGNM)
c         write(CMSGNM,fmt='(3(1pe11.4,1x),a)') xsrc0,ysrc0,zsrc0,
c     &        ' - src illum. in units of RMAX'
c         CALL WRIMSG('REAPAR',CMSGNM)
c         write(CMSGNM,fmt='(4(1pe11.4,1x),a)')isrc0,qsrc0,usrc0,
c     &        vsrc0,
c     &       ' - incident stokes'
c         CALL WRIMSG('REAPAR',CMSGNM)
c      endif

      xvg0=0.4
      yvg0=0.4
      zvg0=-0.2
      xsrc0=1.4
      ysrc0=0.0
      zsrc0=1.2
      isrc0=1.0
      qsrc0=0.0
      usrc0=0.0
      
      
C***********************************************************************
C ... output data
c
      READ(IOPAR,FMT=*,ERR=40)CLINE
      CALL WRIMSG(' ',CLINE)
      READ(IOPAR,FMT=*,ERR=40)rmaxi
      WRITE(CMSGNM,FMT='(1pe13.6,a)')rmaxi
     &     ,' = RMAXI = Image half-size in AU'
      CALL WRIMSG('REAPAR',CMSGNM)
      READ(IOPAR,FMT=*,ERR=40)aperture2
      WRITE(CMSGNM,FMT='(3(f8.1,1x),a)')aperture2
     &     ,' = APERTURE(1-3) = radius of aper 1-3 in AU'
      CALL WRIMSG('REAPAR',CMSGNM)
      READ(IOPAR,FMT=*,ERR=40)thete
      WRITE(CMSGNM,FMT='(f7.2,a)')thete
     &     ,' = THETE = theta angle (deg) of high S/N image'
      CALL WRIMSG('REAPAR',CMSGNM)
      READ(IOPAR,FMT=*,ERR=40)phie
      WRITE(CMSGNM,FMT='(f7.2,a)')phie
     &     ,' = PHIE = phi angle (deg) of high S/N image'
      CALL WRIMSG('REAPAR',CMSGNM)
c      phie=0.

c      READ(IOPAR,FMT=*,ERR=40)xymaxdens
c      WRITE(CMSGNM,FMT='(f7.2,a)')xymaxdens
c     &     ,' =XYMAXDENS = xmax for xydens.dat in units of rstar'
c     CALL WRIMSG('REAPAR',CMSGNM)
      xymaxdens=500000.

      CLOSE (IOPAR)
      RETURN
   40 CONTINUE
      CALL ERRMSG('FATAL','REAPAR',' Error reading .par file')
      RETURN
      END




